@@ -1,15 +1,15 @@
-# $Id: Password.pm,v 1.7 2001/02/24 01:39:13 btrott Exp $
+# $Id: Password.pm,v 1.8 2001/03/05 22:54:25 btrott Exp $
 
 package Net::SSH::Perl::Auth::Password;
 
 use strict;
 
-use Net::SSH::Perl::Constants qw/SSH_CMSG_AUTH_PASSWORD SSH_SMSG_SUCCESS SSH_SMSG_FAILURE/;
+use Net::SSH::Perl::Constants qw( SSH_CMSG_AUTH_PASSWORD SSH_SMSG_SUCCESS SSH_SMSG_FAILURE );
 
 use Net::SSH::Perl::Packet;
-use Net::SSH::Perl::Util qw/_read_passphrase/;
+use Net::SSH::Perl::Util qw( _read_passphrase );
 use Net::SSH::Perl::Auth;
-use base qw/Net::SSH::Perl::Auth/;
+use base qw( Net::SSH::Perl::Auth );
 
 sub new {
     my $class = shift;
