@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.6 2001/03/03 05:43:12 btrott Exp $
+# $Id: Config.pm,v 1.8 2001/03/08 20:33:01 btrott Exp $
 
 package Net::SSH::Perl::Config;
 use strict;
@@ -60,6 +60,15 @@ sub read_config {
     close FH;
 }
 
+sub merge_directive {
+    my($cfg, $line) = @_;
+    my($key, $args) = $line =~ /^\s*(\S+)\s+(.+)$/;
+    return unless $key && $args;
+
+    my $code = $DIRECTIVES{$key}[0] or return;
+    $code->($cfg, $key, $args);
+}
+
 sub _host {
     my($cfg, $key, $host) = @_;
     if ($host ne '*' && $cfg->{_state}{host} !~ /$host/) {
@@ -169,6 +178,15 @@ Furthermore, if you're reading from several config files
 in sequence, values read from the first files will override
 those read from the second, third, fourth, etc. files.
 
+=head2 $cfg->merge_directive($line)
+
+Merges the directive option I<$line> into the configuration
+settings in I<$cfg>. I<$line> should be an option in the format
+used in the config file, eg. I<"BatchMode yes">. This is
+useful for merging in directives that are not necessarily
+in the config file, similar to how the B<-o> option works
+in the I<ssh> command line program.
+
 =head2 $cfg->get($key)
 
 Returns the value of the configuration parameter I<$key>,
